@@ -11,5 +11,11 @@ MODULE_NAME = 'livecoding'
 def register_types():
     qmlRegisterType(ProjectBrowser, MODULE_NAME, 1, 0, ProjectBrowser.__name__)
     qmlRegisterType(FileWatcher, MODULE_NAME, 1, 0, FileWatcher.__name__)
-    qmlRegisterSingletonType(LiveCoding, MODULE_NAME, 1, 0, LiveCoding.__name__,
-                             LiveCoding.qml_singleton_provider)
+    qmlRegisterSingletonType(
+        LiveCoding,
+        MODULE_NAME,
+        1,
+        0,
+        LiveCoding.__name__,
+        LiveCoding.qml_singleton_provider,
+    )
